anyio: High level compatibility layer for multiple asynchronous event loop implementations
==========================================================================================

Description
-----------

High level compatibility layer for multiple asynchronous event loop implementations

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/anyio/

